powered by
This function generates a dataset representing a cone with the option of a sharp or blunted apex.
gen_cone(n = 500, p = 4, h = 5, ratio = 0.5)
A tibble containing the cone with the option of a sharp or blunted apex.
An integer value (default: 500) representing the sample size.
An integervalue (default: 4) representing the number of dimensions.
A numeric value (default: 5) representing the height of the cone.
A numeric value (default: 0.5) representing the radius tip to radius base ratio of the cone. Should be less than 1.
set.seed(20240412) cone <- gen_cone(n = 500, p = 4, h = 5, ratio = 0.5)
Run the code above in your browser using DataLab