powered by
This function generates a dataset representing a rectangular based pyramid.
gen_pyrrect(n = 500, p = 4, h = 5, l_vec = c(3, 2), rt = 0.5)
A tibble containing the rectangular-based pyramid.
An integer value (default: 500) representing the sample size.
An integer value (default: 4) representing the number of dimensions.
A numeric value (default: 5) representing the height of the pyramid.
A numeric vector (default: c(3, 2)) representing the base lengths along the and y of the pyramid.
A numeric value (default: 0.5) representing the tip radius of the pyramid.
set.seed(20240412) pyrrect <- gen_pyrrect(n = 500, p = 4, h = 5, l_vec = c(3, 2), rt = 0.5)
Run the code above in your browser using DataLab