Learn R Programming

cardinalR (version 1.0.6)

gen_trefoil3d: Generate 3-D Trefoil Knot Coordinates (Stereographic Projection)

Description

This function generates coordinates for a 3-D trefoil knot by applying a stereographic projection from 4-D space.

Usage

gen_trefoil3d(n = 500, steps = 5)

Value

A data containing 3-D trefoil knot.

Arguments

n

An integer value (default: 500) representing the sample size.

steps

A numeric value (default: 5) representing the number of steps for the theta parameter.

Examples

Run this code
set.seed(20240412)
trefoil3d <- gen_trefoil3d(n = 500, steps = 5)

Run the code above in your browser using DataLab