Learn R Programming

cardinalR (version 1.0.6)

gen_trefoil4d: Generate 4-D Trefoil Knot Coordinates

Description

This function generates coordinates for a 4-D trefoil knot. The number of points is determined by the length of the theta and phi sequences.

Usage

gen_trefoil4d(n = 500, steps = 5)

Value

A tibble containing 4-D trefoil knot.

Arguments

n

An integer value (default: 500) representing the sample size.

steps

A numeric value (default: 5) representing the number of steps for the theta parameter.

Examples

Run this code
set.seed(20240412)
trefoil4d <- gen_trefoil4d(n = 500, steps = 5)

Run the code above in your browser using DataLab