powered by
This function generates a dataset representing a cube with a hole.
gen_unifcubehole(n = 5000, p = 4, r_hole = 0.5)
A data containing the cube data with a hole.
A numeric value (default: 500) representing the sample size.
A numeric value (default: 4) representing the number of dimensions.
A numeric value (default: 0.5) representing the radius of the hole.
set.seed(20240412) cubehole <- gen_unifcubehole(n = 1000, p = 4)
Run the code above in your browser using DataLab