powered by
This function generates random noise dimensions by adding wavy patterns.
gen_wavydims1(n = 500, p = 4, theta = seq(pi/6, 12 * pi/6, length.out = 500))
A data containing the generated random noise dimensions.
A numeric value (default: 500) representing the sample size.
A numeric value (default: 4) representing the number of dimensions.
A numeric vector representing the nonlinearity along each dimensions.
set.seed(20240412) gen_wavydims1(n = 500, p = 4, theta = seq(pi / 6, 12 * pi / 6, length.out = 500))
Run the code above in your browser using DataLab