powered by
This function generates random noise dimensions by adding wavy patterns.
gen_wavydims3(n = 500, p = 4, data)
A data containing the generated random noise dimensions.
A numeric value (default: 500) representing the sample size.
A numeric value (default: 4) representing the number of dimensions.
A matrix representing the first three dimensions of the data structure.
set.seed(20240412) df <- gen_scurve(n = 500) |> as.matrix() gen_wavydims3(n = 500, p = 3, data = df)
Run the code above in your browser using DataLab