Learn R Programming

cardinalR (version 1.0.6)

gen_hole: Remove points within a spherical hole in the middle

Description

Remove points within a spherical hole in the middle

Usage

gen_hole(df, anchor = NULL, r = 0.5)

Value

A tibble with the hole removed.

Arguments

df

A tibble of coordinates.

anchor

A numeric vector giving the center of the hole.

r

A numeric value for the hole radius.

Examples

Run this code
set.seed(20240412)
df <- gen_scurve(n = 1000)
gen_hole(df, r = 0.5)

Run the code above in your browser using DataLab