powered by
Remove points within a spherical hole in the middle
gen_hole(df, anchor = NULL, r = 0.5)
A tibble with the hole removed.
A tibble of coordinates.
A numeric vector giving the center of the hole.
A numeric value for the hole radius.
set.seed(20240412) df <- gen_scurve(n = 1000) gen_hole(df, r = 0.5)
Run the code above in your browser using DataLab