powered by
This function generates coordinates for a 3-D trefoil knot by applying a stereographic projection from 4-D space.
gen_trefoil3d(n = 500, steps = 5)
A data containing 3-D trefoil knot.
An integer value (default: 500) representing the sample size.
A numeric value (default: 5) representing the number of steps for the theta parameter.
set.seed(20240412) trefoil3d <- gen_trefoil3d(n = 500, steps = 5)
Run the code above in your browser using DataLab