powered by
This function generates coordinates for a 4-D trefoil knot. The number of points is determined by the length of the theta and phi sequences.
gen_trefoil4d(n = 500, steps = 5)
A tibble containing 4-D trefoil knot.
An integer value (default: 500) representing the sample size.
A numeric value (default: 5) representing the number of steps for the theta parameter.
set.seed(20240412) trefoil4d <- gen_trefoil4d(n = 500, steps = 5)
Run the code above in your browser using DataLab