powered by
This function generates random noise dimensions by adding wavy patterns.
gen_wavydims2(n = 500, p = 4, x1_vec)
A data containing the generated random noise dimensions.
A numeric value (default: 500) representing the sample size.
A numeric value (default: 4) representing the number of dimensions.
A numeric vector representing the first dimension of the data structure.
set.seed(20240412) theta <- seq(0, 2 * pi, length.out = 500) x1 <- sin(pi) * cos(theta) gen_wavydims2(n = 500, p = 4, x1_vec = x1)
Run the code above in your browser using DataLab